"""
Copyright 2020 Goldman Sachs.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
"""

NO_REQUEST_ID = 'no-request-id'


def log_debug(request_id, logger, fmt_str, *args, **kwargs):
    logger.debug(f'{request_id or NO_REQUEST_ID}: {fmt_str}', *args, **kwargs)


def log_warning(request_id, logger, fmt_str, *args, **kwargs):
    logger.warning(f'{request_id or NO_REQUEST_ID}: {fmt_str}', *args, **kwargs)


def log_info(request_id, logger, fmt_str, *args, **kwargs):
    logger.info(f'{request_id or NO_REQUEST_ID}: {fmt_str}', *args, **kwargs)
